@@ -657,6 +657,25 @@ globus_gridftp_server_control_attr_set_epsv_ip(
     return GLOBUS_SUCCESS;
 }
 
+globus_result_t
+globus_gridftp_server_control_attr_set_ipv6(
+    globus_gridftp_server_control_attr_t    in_attr,
+    globus_bool_t                           ipv6)
+{
+    globus_i_gsc_attr_t *                   attr;
+    GlobusGridFTPServerName(globus_gridftp_server_control_attr_set_ipv6);
+
+    if(in_attr == NULL)
+    {
+        return GlobusGridFTPServerErrorParameter("server_attr");
+    }
+    attr = (globus_i_gsc_attr_t *) in_attr;
+
+    attr->ipv6 = ipv6;
+
+    return GLOBUS_SUCCESS;
+}
+
 globus_result_t
 globus_gridftp_server_control_attr_set_message(
     globus_gridftp_server_control_attr_t    in_attr,
